allSynonymsRef: Example dataset: allSynonymsRef

allSynonymsRefR Documentation

Example dataset: allSynonymsRef

Description

This dataset contains the valid names and respective listed synonyms for all reptile species cataloged in The Reptile Database.

Usage

allSynonymsRef

Format

A dataframe with 113,377 rows and 4 variables:

species

A character vector with known current valid name for all reptile species cataloged in The Reptile Database website (download: March 27th, 2026)

synonym

A character column with the respective synonyms for all reptile species cataloged in The Reptile Database website information (download: March 27th, 2026)

ref

A charater column with the synonyms and respective references that used it

refYear

An integer with the publication year mentionning the refered synonyms

The data was sampled from The Reptile Database website https://reptile-database.reptarium.cz using function letsRept::reptSynonyms(letsRept::allReptiles)


letsRept documentation built on June 22, 2026, 9:09 a.m.