Learn R Programming

letsRept (version 1.1.0)

br_snakes_atlas: Example dataset: br_snakes_atlas

Description

This dataset contains Table S3, the georeferenced type localities, from the supplementary material provided by Nogueira et al., (2019)

Usage

br_snakes_atlas

Arguments

Format

A dataframe with 411 rows and 3 colums:

species

A character vector with known current valid name for all reptile species cataloged in The Reptile Database website

latitude

Latitude coordinates in decimal degrees

longitude

Longitude coordinates in decimal degrees

References

Nogueira, C. C., Argôlo, A. J. S., Arzamendia, V., Azevedo, J. A. R., Barbo, F. E., Bérnils, R. S., … & Martins, M. (2019). Atlas of Brazilian Snakes: Verified Point-Locality Maps to Mitigate the Wallacean Shortfall in a Megadiverse Snake Fauna. South American Journal of Herpetology, 14(sp1), 1–274. http://dx.doi.org/10.2994/sajh-d-19-00120.1