letsRept: letsRept: An Interface to the Reptile Database

letsReptR Documentation

letsRept: An Interface to the Reptile Database

Description

The letsRept package provides functions to interact with and extract taxonomic and distributional data from the Reptile Database (https://reptile-database.reptarium.cz). It supports advanced search queries, extraction of species names, synonyms, higher taxa, and related metadata for herpetological research.

Author(s)

Maintainer: João Paulo dos Santos Vieira-Alencar joaopaulo.valencar@gmail.com (ORCID)

Authors:

See Also

Useful links:


letsRept documentation built on June 22, 2026, 9:09 a.m.