| letsRept_ReptTraits | R Documentation |
This dataset is a version of ReptTraits (Oskyrko et al. 2024) with two additional columns.
letsRept_ReptTraits
A dataframe with 12,060 rows and 50 variables. The first three columns are:
Species name as in the original ReptTraits database
Current valid name according to the May 2025 version of the Reptile Database
Status from reptSync and reptSplitCheck. Additional status are: "extinct" and "manual_fix"
The original data source is from Oskyrko et al. (2024); The new nomenclature in the RDB column was collected from the Reptile Database website https://reptile-database.reptarium.cz using functions reptSync and reptSplitCheck
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.