| reptSpecies | R Documentation |
Retrieves a list of reptile species from The Reptile Database (RDB) based on a search URL, and optionally returns detailed taxonomic information for each species. This function can also save progress to disk during sampling and extract species-specific URLs for further use.
reptSpecies(
url = NULL,
showProgress = TRUE,
dataList = NULL,
taxonomicInfo = FALSE,
fullHigher = FALSE,
getLink = FALSE,
cores = 1
)
url |
Character string. A search URL generated via an advanced search on the RDB website or with |
showProgress |
Logical. If |
dataList |
Optional. A data frame with columns |
taxonomicInfo |
Logical. If |
fullHigher |
Logical. If |
getLink |
Logical. If |
cores |
Integer. Number of CPU cores to use for parallel processing. Default is |
If taxonomicInfo = FALSE (default), returns a character vector of species names.
If taxonomicInfo = TRUE, returns a data frame with columns:
order, suborder (if available), family, genus, species, author, and year.
If fullHigher = TRUE, includes an additional column with the full higher taxa classification.
If getLink = TRUE, includes a column with the URL for each species’ page on RDB.
reptAdvancedSearch, reptSynonyms, reptSearch
boa <- reptSpecies(reptAdvancedSearch(genus = "Boa"),
taxonomicInfo = TRUE,
cores = 2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.