reptTidySyn: Printing reptSync and reptSplitCheck outcomes in a tidy way

View source: R/reptTidySyn.R

reptTidySynR Documentation

Printing reptSync and reptSplitCheck outcomes in a tidy way

Description

Prints the data frame derived from reptSync or reptSplitCheck in a tidy way. Optionally, it filters the data frame for species with unresolved nomenclature only.

Usage

reptTidySyn(df, filter = NULL)

Arguments

df

The data frame derivated from reptSync

filter

Logical. If TRUE will print only the species entries with unresolved nomenclature (e.g.: ambiguous or not_found). Default is TRUE

Value

Invisibly returns NULL. Used for side-effect printing only.

Examples

df <- data.frame(
  query = c("Genus epithet 1", 
              "Genus epithet 2",
              "Genus epithet 3",
              "Genus epithet 4",
              "Genus epithet 5"),
  RDB = c("Genus epithet 1.1; Genus epithet 1.2",
                "Genus epithet 2",
                "Genus epithet 3",
                "Not found",
                "Genus epithet 5.1; Genus epithet 5.2; Genus epithet 5.3"),
  status = c("ambiguous", 
             "updated",
             "up_to_date",
             "not_found",
             "ambiguous"),
  stringsAsFactors = FALSE
)
reptTidySyn(df, filter = c("ambiguous", "not_found"))


letsRept documentation built on June 22, 2026, 9:09 a.m.