| allSynonymsRef | R Documentation |
This dataset contains the valid names and respective listed synonyms for all reptile species cataloged in The Reptile Database.
allSynonymsRef
A dataframe with 113,377 rows and 4 variables:
A character vector with known current valid name for all reptile species cataloged in The Reptile Database website (download: March 27th, 2026)
A character column with the respective synonyms for all reptile species cataloged in The Reptile Database website information (download: March 27th, 2026)
A charater column with the synonyms and respective references that used it
An integer with the publication year mentionning the refered synonyms
The data was sampled from The Reptile Database website https://reptile-database.reptarium.cz using function letsRept::reptSynonyms(letsRept::allReptiles)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.