View source: R/reptSplitCheck.R
| reptSplitCheck | R Documentation |
Check for potential taxonomic splits in a query
reptSplitCheck(
x,
pubDate = NULL,
includeAll = FALSE,
verbose = FALSE,
cores = 1,
showProgress = TRUE,
exact = FALSE
)
x |
A character vector of species names to check. Usually from a database. |
pubDate |
Integer. An year (e.g., 2019) used as a reference date from when to check potential taxonomic split. Either a single year applied to all queried species, or a vector of years with the same length as x, providing a reference year for each species individually. |
includeAll |
Logical; If |
verbose |
Logical; If |
cores |
Integer. Number of CPU cores to use for parallel processing. Default is |
showProgress |
Logical. If |
exact |
Logical. Will search queried names for exact matches only (e.g., does not retrieve "Tantilla cf. melanocephala" when searching for "Tantilla melanocephala"). Default is |
A data frame with the following columns:
query: the original input names.
RDB: the best-matching valid names according to The Reptile Database.
status: a status label indicating the result of the match ("check_split", "up_to_date", "not_found", or "failed").
query <- c(
"Atractus dapsilis",
"Atractus trefauti",
"Atractus snethlageae",
"Tantilla melanocephala",
"Oxybelis aeneus",
"Oxybelis rutherfordi",
"Vieira-Alencar authoristicus",
"Oxybelis aeneus",
"Bothrops pauloensis")
result <- reptSplitCheck(x=query,
pubDate = 2019,
cores = 2,
showProgress = FALSE)
result <- reptSplitCheck(x=query,
pubDate = 2019,
cores = 2,
showProgress = FALSE,
includeAll = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.