| reptSynonyms | R Documentation |
Retrieves a data frame containing the current valid names of reptile species along with all their recognized synonyms, as listed in The Reptile Database (RDB). Optionally, the references citing each synonym can also be included.
reptSynonyms(x, getRef = FALSE, showProgress = TRUE, cores = 1)
x |
A character string with a species binomial or a data frame with columns |
getRef |
Logical. If |
showProgress |
Logical. If |
cores |
Integer. Number of CPU cores to use for parallel processing. Default is |
A data frame with columns:
species: The valid species name according to RDB.
synonym: Recognized synonyms and chresonyms for the species. Chresonyms are usually separated from authors with an emdash.
reference (optional): If getRef = TRUE, the citation where the synonym was reported.
Uetz, P., Freed, P., Aguilar, R., Reyes, F., Kudera, J., & Hošek, J. (eds.) (2025). The Reptile Database. Retrieved from http://www.reptile-database.org
reptSpecies, reptAdvancedSearch
# Filter species belonging to genus Boa
boa <- letsRept::allReptiles[grep("^Boa\\s", letsRept::allReptiles$species), ]
# Retrieve synonyms (without references)
boa_syn <- reptSynonyms(boa, getRef = FALSE, cores = 2)
Bconstrictor_syn <- reptSynonyms(x = "Boa constrictor")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.